aboutsummaryrefslogtreecommitdiff
path: root/gcc/sel-sched.c
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/sel-sched.c')
-rw-r--r--gcc/sel-sched.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gcc/sel-sched.c b/gcc/sel-sched.c
index c798935..bd32ab5 100644
--- a/gcc/sel-sched.c
+++ b/gcc/sel-sched.c
@@ -396,7 +396,7 @@ typedef struct fur_static_params *fur_static_params_p;
typedef struct cmpd_local_params *cmpd_local_params_p;
typedef struct moveop_static_params *moveop_static_params_p;
/* Set of hooks and parameters that determine behaviour specific to
move_op or find_used_regs functions. */
struct code_motion_path_driver_info_def
{
@@ -6450,7 +6450,7 @@ code_motion_path_driver (insn_t insn, av_set_t orig_ops, ilist_t path,
{
/* We have already found an original operation on this branch, do not
go any further and just return TRUE here. If we don't stop here,
- function can have exponential behaviour even on the small code
+ function can have exponential behavior even on the small code
with many different paths (e.g. with data speculation and
recovery blocks). */
if (sched_verbose >= 6)
@@ -396,7 +396,7 @@ typedef struct fur_static_params *fur_static_params_p;
typedef struct cmpd_local_params *cmpd_local_params_p;
typedef struct moveop_static_params *moveop_static_params_p;
-/* Set of hooks and parameters that determine behaviour specific to
+/* Set of hooks and parameters that determine behavior specific to
move_op or find_used_regs functions. */
struct code_motion_path_driver_info_def